@@ -74,7 +74,7 @@ def get_classes(sub: str) -> Dict[str, Type[BasePlugin]]:
     for file_name in os.listdir(sub_path):
         if not file_name.startswith("__") and file_name.endswith(".py"):
             module_name = file_name[:-3]
-            module = importlib.import_module("emonoda.plugins.{}.{}".format(sub, module_name))
+            module = importlib.import_module(f"emonoda.plugins.{sub}.{module_name}")
             plugin_class = getattr(module, "Plugin")
             for plugin_name in plugin_class.PLUGIN_NAMES:
                 classes[plugin_name] = plugin_class
