@@ -42,81 +42,84 @@ except ImportError:
 
 # =====
 class Plugin(BaseClient):
-    PLUGIN_NAME = "ktorrent"
+    PLUGIN_NAMES = ["ktorrent"]
 
-    def __init__(self, **kwargs: Any) -> None:  # pylint: disable=super-init-not-called
+    def __init__(self, service: str, **kwargs: Any) -> None:  # pylint: disable=super-init-not-called
         self._init_bases(**kwargs)
 
         if dbus is None:
             raise RuntimeError("Required module dbus")
 
-        self._bus = dbus.SessionBus()
-        self._core = self._bus.get_object("org.ktorrent.ktorrent", "/core")
-        self._settings = self._bus.get_object("org.ktorrent.ktorrent", "/settings")
+        self.__service = service
 
-        if self._settings.useSaveDir():
+        self.__bus = dbus.SessionBus()
+        self.__core = self.__bus.get_object(self.__service, "/core")
+        self.__settings = self.__bus.get_object(self.__service, "/settings")
+
+        if self.__settings.useSaveDir():
             raise RuntimeError("Turn off the 'path by default' in KTorrent settings")
 
     @classmethod
     def get_options(cls) -> Dict[str, Option]:
-        return cls._get_merged_options()
+        return cls._get_merged_options({
+            "service": Option(default="org.kde.ktorrent", help="D-Bus service, use 'org.ktorrent.ktorrent' for old client"),
+        })
 
-    # ===
+    # =====
+
+    @hash_or_torrent
+    def start_torrent(self, torrent_hash: str) -> None:
+        self.__get_torrent_obj(torrent_hash)  # XXX: raise NoSuchTorrentError if torrent does not exist
+        self.__core.start(torrent_hash)
+
+    @hash_or_torrent
+    def stop_torrent(self, torrent_hash: str) -> None:
+        self.__get_torrent_obj(torrent_hash)
+        self.__core.stop(torrent_hash)
+
+    @check_torrent_accessible
+    def load_torrent(self, torrent: Torrent, prefix: str) -> None:
+        self.__settings.setLastSaveDir(prefix)
+        self.__core.loadSilently(torrent.get_path(), "")
 
     @hash_or_torrent
     def remove_torrent(self, torrent_hash: str) -> None:
-        self._get_torrent_obj(torrent_hash)  # XXX: raise NoSuchTorrentError if torrent does not exist
-        self._core.remove(torrent_hash, False)
-
-    @check_torrent_accessible
-    def load_torrent(self, torrent: Torrent, prefix: str="") -> None:
-        if prefix:
-            self._settings.setLastSaveDir(prefix)
-        self._core.loadSilently(torrent.get_path(), "")
+        self.__get_torrent_obj(torrent_hash)
+        self.__core.remove(torrent_hash, False)
 
     @hash_or_torrent
     def has_torrent(self, torrent_hash: str) -> bool:
         try:
-            self._get_torrent_obj(torrent_hash)
+            self.__get_torrent_obj(torrent_hash)
             return True
         except NoSuchTorrentError:
             return False
 
     def get_hashes(self) -> List[str]:
-        return list(map(str.lower, self._core.torrents()))
-
-    @hash_or_torrent
-    def get_torrent_path(self, torrent_hash: str) -> str:
-        raise RuntimeError("KTorrent can not return a path of the torrent file")
+        return list(map(str.lower, self.__core.torrents()))
 
     @hash_or_torrent
     def get_data_prefix(self, torrent_hash: str) -> str:
-        return str(self._get_torrent_obj(torrent_hash).dataDir())
+        return str(self.__get_torrent_obj(torrent_hash).dataDir())
 
     def get_data_prefix_default(self) -> str:
-        raise RuntimeError("KTorrent can not return a default data path")
+        return str(self.__settings.saveDir())
 
-    # ===
+    # =====
 
     @hash_or_torrent
     def get_full_path(self, torrent_hash: str) -> str:
-        return str(self._get_torrent_obj(torrent_hash).pathOnDisk())
+        return str(self.__get_torrent_obj(torrent_hash).pathOnDisk())
 
     @hash_or_torrent
     def get_file_name(self, torrent_hash: str) -> str:
-        return str(self._get_torrent_obj(torrent_hash).name())
+        return str(self.__get_torrent_obj(torrent_hash).name())
 
     @hash_or_torrent
-    def is_single_file(self, torrent_hash: str) -> bool:
-        return (self._get_torrent_obj(torrent_hash).numFiles() == 0)
-
-    @hash_or_torrent
-    def get_files(self, torrent_hash: str, on_fs: bool=False) -> Dict[str, TorrentEntryAttrs]:
-        torrent_obj = self._get_torrent_obj(torrent_hash)
-        prefix = (str(torrent_obj.pathOnDisk()) if on_fs else "")
+    def get_files(self, torrent_hash: str) -> Dict[str, TorrentEntryAttrs]:
+        torrent_obj = self.__get_torrent_obj(torrent_hash)
         count = torrent_obj.numFiles()
         name = str(torrent_obj.name())
-
         if count == 0:  # Single file
             flist = [(name, int(torrent_obj.totalSize()))]
         else:
@@ -127,15 +130,15 @@ class Plugin(BaseClient):
                 )
                 for index in range(count)
             ]
-        return build_files(prefix, flist)
+        return build_files("", flist)
 
-    # ===
+    # =====
 
-    def _get_torrent_obj(self, torrent_hash: str) -> Any:
+    def __get_torrent_obj(self, torrent_hash: str) -> Any:
         if torrent_hash not in self.get_hashes():
             raise NoSuchTorrentError("Unknown torrent hash")
         try:
-            torrent_obj = self._bus.get_object("org.ktorrent.ktorrent", "/torrent/" + torrent_hash)
+            torrent_obj = self.__bus.get_object(self.__service, "/torrent/" + torrent_hash)
             assert str(torrent_obj.infoHash()) == torrent_hash
             return torrent_obj
         except dbus.exceptions.DBusException as err:
